# Clear memory and set random seed =============================================
#
rm(list = ls()) # clear memory
graphics.off()  # clear all plots
cat("\014")     # clear console (same as Ctrl-L in console)
library(readr)

# Select experiment to analyse (1 = A and 2 = B)
experiment = 2

# For experiment 1, data collection for subject nr 5 was not completed because
# the subject age exceeded the preregistered age maximum.

# READ IN ALL SUBJECTS RAW DATA AND ADD EXTRA VARIABLES ========================
#
wd = paste('C:/Users/',Sys.getenv("USERNAME"),'/Dropbox/Rasmus_Eklund/RasmusPhD/AAN/AAN_data/exp',experiment,sep = '')
setwd(wd)

path = getwd()
folder = dir(pattern = 'fp') # list of folders with "fp"
df = data.frame()

for (fps in 1:length(folder)){
  setwd(paste(path,folder[fps],sep = '/')) # enter current fp
  fp = dir(pattern = 'fp')[2]
  
  tmp = read_delim(fp, "\t", escape_double = FALSE, trim_ws = TRUE, skip = 5)
  #create extra variables
  tmp$unaware = 1
  tmp$unaware[tmp$aware==1] = 0
  tmp$type = 0
  tmp$type[tmp$cond == 1] = "critical"
  tmp$type[tmp$cond == 2] = "control"
  tmp$type[tmp$cond == 3] = "catch"
  df=rbind(tmp,df)
  
  setwd('..')
}
rm(fp,tmp)

# CALCULATE BEHAVIORAL DATA FOR EVERY SUBJECT ==================================
#
d=data.frame()
# fp = 1
for (fp in folder){
  fp = as.integer(substr(fp,3,nchar(fp)))
  #add subject nr
  tmp=data.frame(fp)
  
  #Number of trials rated as aware (2 or 3) in 
  # control trials (max 80)
  tmp$Hit_control = sum(df$aware[df$type=='control' & df$fp==tmp$fp])
  
  # catch trials (max 80)
  tmp$Aware_catch = sum(df$aware[df$type=='catch' & df$fp==tmp$fp])
  
  # critical trials (max 640)
  tmp$Aware_crit = sum(df$aware[df$type=='critical' & df$fp==tmp$fp])
  
  #Number of trials rated as unaware (1) in critical trials
  tmp$Unaware_crit = sum(df$unaware[df$type=='critical' & df$fp==tmp$fp])
  
  tmp$levelcrit = mean(df$level[df$fp==tmp$fp & df$type=='critical'])
  tmp$levelcontrol = mean(df$level[df$fp==tmp$fp & df$type=='control'])
  
  # CALCULATE D PRIME AND CRITERION C
  #
  # hit-rate = 'yes' when signal present, fa-rate = 'yes' no signal
  # correct for floor and ceiling (add half a trial to subject performance 
  # and divide by all trials + 1)
  tmp$Aware_catch_corrected = (tmp$Aware_catch+0.5)/(80+1)
  tmp$Aware_crit_corrected = (tmp$Aware_crit+0.5)/(640+1)
  # Dprime and criterion c
  tmp$dprime = qnorm(tmp$Aware_crit_corrected) - qnorm(tmp$Aware_catch_corrected)
  tmp$criterion = - (1/2) * (qnorm(tmp$Aware_crit_corrected) + qnorm(tmp$Aware_catch_corrected))
    #-----------------------------------------------------------------------------
  d=rbind(d,tmp)
  rm(tmp)
}
rm(list=setdiff(ls(), c("d","df",'experiment')))

# Load other variables into dataset ============================================
#
# Sex, age and handedness
sexAge = read_csv(paste("ParticipantsEEG_exp",experiment,".csv",sep = ""), col_types = cols_only(Age = col_guess(), Hand = col_guess(), `Sex (m=1, f=0)` = col_guess(), fp = col_guess()))
d <- merge(d,sexAge,by="fp", all = F)
rm(sexAge)

# Mean amplitudes
meanAmps <- read_csv(paste("Amps_AAN_exp",experiment,".csv",sep = ''), col_names = TRUE)
#experiment 2
colnames(x = meanAmps)[1] = 'fp'

d <- merge(d,meanAmps,by=c("fp"), all = F)
rm(meanAmps)
#write_csv(d, path = paste('C:/Users/',Sys.getenv("USERNAME"),'/Dropbox/Rasmus_Eklund/RasmusPhD/AAN/AAN_data/exp',experiment,'/AAN_data.csv',sep = ''))

#=Table 1 (Make it)=============================================================
#
# aware crit, unaware crit, hit control, false alarms
x = c(4,5,2,3)
div = c(640,640,80,80)

table1 = data.frame()

for (i in 1:4){
  tmp = mean(d[,x[i]])/div[i]*100
  tmp1 = sd(d[,x[i]])/div[i]*100
  table1 = rbind(table1,c(tmp,tmp1))
}

colnames(table1) = c('Mean','SD')
rownames(table1) = c('Control: Hits (%)', 'Catch: False alarms (%)', 
                     'Critical: Aware (%)', 
                     'Critical: Unaware (%)')
table1 = round(table1,1)
rm(list=setdiff(ls(), c("d","df",'table1','experiment')))

#=Table 2 (Make it)=============================================================
# Exclude subjects if applicable
x = c(18,20)
if (experiment==2){
  d = d[d$Fp_N1control==1,]
  x = c(18,19)
}
#
# Sum aan, lp
table2 = data.frame()

for (i in 1:2){
  n = nrow(d)
  meanAmp = mean(d[,x[i]])
  sdAmp = sd(d[,x[i]])
  ciLeft = mean(d[,x[i]])-qt(0.975,df=n-1)*sd(d[,x[i]])/sqrt(n)
  ciRight = mean(d[,x[i]])+qt(0.975,df=n-1)*sd(d[,x[i]])/sqrt(n)
  meanTrialsA = mean(d$nAC)
  meanTrialsU = mean(d$nUC)
  sdTrialsA = sd(d$nAC)
  sdTrialsU = sd(d$nUC)
  table2 = rbind(table2,c(n, meanAmp, sdAmp, ciLeft, ciRight, meanTrialsA, sdTrialsA, meanTrialsU, sdTrialsU))
}

colnames(table2) = c('N', 'Mean (V)','SD' ,'CI-','CI+', 'Mean trials aware', 'SD', 'Mean trials unaware', 'SD')
rownames(table2) = c('AAN', 'LP')
table2 = round(table2,2)
rm(list=setdiff(ls(), c("d","df",'table1','table2','experiment')))

# Extra plots

# Plot percent aware for all subjects ==========================================
#
plot(d$Aware_crit/640,ylim = c(0,1),main = round(mean(d$Aware_crit/640*100),2),xlab = 'FP', ylab = 'Percent aware')
abline(0.5,0)
abline(mean(d$Aware_crit)/640,0, lty = 3, col = 'red')

# check proportion of awareness ratings per condition per subject
table(df$cond, df$subj_resp, df$fp)

# Check awareness level per block ==============================================
par(mfrow=c(5,4))
# plot all subjects aware level over blocks
for (fp in 1:16){
  a = table(df$aware[df$type=='critical' & df$fp==fp],df$block[df$type=='critical' & df$fp==fp])
  c = table(df$aware[df$type=='catch' & df$fp==fp],df$block[df$type=='catch' & df$fp==fp])
  ma = mean(a[2,]/80)
  mc = mean(df$aware[df$type=='catch' & df$fp==fp])
  plot(a[2,]/80, ylim = c(0,80)/80,
       main = bquote(expr = 'fp =' ~ .(fp) ~ ', Aware = ' ~ .(round(ma*100,2))~'%'), 
       xlab = 'Block', ylab = 'Nr critical trials aware out of 80', 
       pch = 21, col = 'black', bg = 'red', cex = 1)
  points(c[2,]/10, pch = 22, col = 'black', bg = 'blue', cex = 0.8)
  abline(a = 0.5,b = 0) # 50 % aware line
  abline(a = ma, b = 0, lty = 3, col = 'red')
  abline(a = mc, b = 0, lty = 4, col = 'blue')
}
for (fp in 17:32){
  a = table(df$aware[df$type=='critical' & df$fp==fp],df$block[df$type=='critical' & df$fp==fp])
  c = table(df$aware[df$type=='catch' & df$fp==fp],df$block[df$type=='catch' & df$fp==fp])
  ma = mean(a[2,]/80)
  mc = mean(df$aware[df$type=='catch' & df$fp==fp])
  plot(a[2,]/80, ylim = c(0,80)/80,
       main = bquote(expr = 'fp =' ~ .(fp) ~ ', Aware = ' ~ .(round(ma*100,2))~'%'), 
       xlab = 'Block', ylab = 'Nr critical trials aware out of 80', 
       pch = 21, col = 'black', bg = 'red', cex = 1)
  points(c[2,]/10, pch = 22, col = 'black', bg = 'blue', cex = 0.8)
  abline(a = 0.5,b = 0) # 50 % aware line
  abline(a = ma, b = 0, lty = 3, col = 'red')
  abline(a = mc, b = 0, lty = 4, col = 'blue')
}

rm(list=setdiff(ls(), c("d","df",'experiment','table1', 'table2')))